SortAndMerge

Struct SortAndMerge 

pub struct SortAndMerge<const N: usize = 32> { /* private fields */ }
Strategy that stores all observations and sorts them on emission.

This preserves all observations exactly but uses more memory than bucketing strategies. This uses a SmallVec (default size 32, memory usage of 256 bytes) to avoid allocations for small numbers of observations.

The const generic N controls the inline capacity before heap allocation.

Implementations

Source

impl<const N: usize> SortAndMerge<N>

pub fn new() -> Self

Create a new sort-and-merge strategy.