pub struct SortAndMerge<const N: usize = 32> { /* private fields */ }Expand description
Strategy that stores all observations and sorts them on emission.
This preserves all observations exactly but uses more memory than bucketing strategies.
This uses a SmallVec (default size 32, memory usage of 256 bytes) to avoid allocations for small numbers of observations.
The const generic N controls the inline capacity before heap allocation.
Implementations